@@ -57,6 +57,10 @@ SERVICE_ROLE = (
     'This command will also create the default EC2 instance profile '
     '<code>' + EC2_ROLE_NAME + '</code>.')
 
+AUTOSCALING_ROLE = (
+    '<p>Allows EMR to call other service such as AnyScale and CloudWatch on your behalf.</p>'
+)
+
 USE_DEFAULT_ROLES = (
     '<p>Uses --service-role=<code>' + EMR_ROLE_NAME + '</code>, and '
     '--ec2-attributes InstanceProfile=<code>' + EC2_ROLE_NAME + '</code>'
@@ -83,8 +87,8 @@ RELEASE_LABEL = (
     '<p>For details about the releases available in Amazon Elastic MapReduce,'
     ' go to Releases Available in Amazon Elastic MapReduce in the'
     ' Amazon Elastic MapReduce Documentation.</p>'
-    '<p>http://docs.aws.amazon.com/ElasticMapReduce/latest/Applications/'
-    'emr-release.html</p><p>Please use ami-version if you want to specify AMI'
+    '<p>http://docs.aws.amazon.com/emr/latest/ReleaseGuide/'
+    'emr-release-components.html</p><p>Please use ami-version if you want to specify AMI'
     ' Versions for your Amazon EMR cluster (3.x and 2.x)</p>')
 
 CONFIGURATIONS = (
@@ -112,12 +116,31 @@ INSTANCE_GROUPS = (
     ' of Amazon EC2 instances to create instance groups in a cluster.</p>'
     '<p> Each instance group takes the following parameters: '
     '<code>[Name], InstanceGroupType, InstanceType, InstanceCount,'
-    ' [BidPrice], [EbsConfiguration]</code>. [EbsConfiguration] is optional.'
-    ' EbsConfiguration takes the following parameters: <code>EbsOptimized</code>'
+    ' [BidPrice], [EbsConfiguration], [AutoScalingPolicy]</code>. [EbsConfiguration] and [AutoScalingPolicy]'
+    ' are optional. EbsConfiguration takes the following parameters: <code>EbsOptimized</code>'
     ' and <code>EbsBlockDeviceConfigs</code>. EbsBlockDeviceConfigs is an array of EBS volume'
     ' specifications, which takes the following parameters : <code>([VolumeType], '
     ' [SizeInGB], Iops)</code> and VolumesPerInstance which is the count of EBS volumes'
-    ' per instance with this specification.</p>')
+    ' per instance with this specification.</p>'
+    '<p> AutoScalingPolicy takes the following parameters: <code>Constraints</code> and <code>Rules</code>.'
+    ' Constraints takes the following parameters: <code>MinCapacity, MaxCapacity</code>. Rules is a list of AutoScaling'
+    ' rules associated to the policy. Each rule has the following parameters: <code> Name, [Description], Action, '
+    ' Trigger</code>. Action takes the following parameters: <code>Market, SimpleScalingPolicyConfiguration'
+    ' (AdjustmentType, ScalingAdjustment)</code>. Trigger takes <code>CloudWatchAlarmDefinition(AlarmNamePrefix,'
+    ' ComparisonOperator, EvaluationPeriods, MetricName, Namespace, Period, Statistic, Threshold, Unit,'
+    ' [Dimensions])</code>.</p>')
+
+INSTANCE_FLEETS = (
+    '<p> A specification of the number and type'
+    ' of Amazon EC2 instances used to create instance fleets in a cluster.</p>'
+    '<p> Each instance fleet takes the following parameters: '
+    '<code>[Name], InstanceFleetType, InstanceTypeConfigs, TargetOnDemandCapacity or TargetSpotCapacity,'
+    ' [BidPrice], [EbsConfiguration]</code>. [EbsConfiguration] is optional.'
+    ' EbsConfiguration takes the following parameters: <code>EbsOptimized</code>'
+    ' and <code>EbsBlockDeviceConfigs</code>. EbsBlockDeviceConfigs is an array of EBS volume'
+    ' specifications, which takes the following parameters : <code>([VolumeType],'
+    ' [SizeInGB], Iops)</code> and VolumesPerInstance. VolumesPerInstance is the count of EBS'
+    ' volumes per instance with this specification.</p>')
 
 INSTANCE_TYPE = (
     '<p>Shortcut option for --instance-groups. A specification of the '
@@ -179,6 +202,12 @@ TERMINATION_PROTECTED = (
     'user intervention, or in the event of an error. Termination protection '
     'is off by default.</p>')
 
+SCALE_DOWN_BEHAVIOR = (
+    '<p>Specifies the Scale down behavior for the cluster.</p>'
+    '<p>The valid values are:'
+    '<li>TERMINATE_AT_TASK_COMPLETION</li>'
+    '<li>TERMINATE_AT_INSTANCE_HOUR</li></p>'
+)
 VISIBILITY = (
     '<p>Specifies whether the cluster is visible to all IAM users of'
     ' the AWS account associated with the cluster. If set to '
@@ -336,3 +365,19 @@ CREATE_CLUSTER_DESCRIPTION = (
     'Values for variables Instance Profile (under EC2 Attributes),'
     ' Service Role, Log URI, and Key Name (under EC2 Attributes) can be set in'
     ' the AWS CLI config file using the "aws configure set" command.\n')
+
+SECURITY_CONFIG = (
+    '<p>The name of a security configuration in the AWS account. '
+    'Use <code>list-security-configurations</code> to get a list of available '
+    'security configurations.</p>')
+
+CUSTOM_AMI_ID = (
+    '<p>Use custom AMI ID to launch cluster</p>')
+
+EBS_ROOT_VOLUME_SIZE = (
+    '<p>Customize EBS root volume size.</p>'
+)
+
+REPO_UPGRADE_ON_BOOT = (
+    '<p>Repo upgrade option on instance boot. This can be used only with custom AMIs</p>'
+)
